@@ -127,10 +127,10 @@ def step_task_request_text_with_name_to_endpoint(context: Context, method: Reque
     assert isinstance(direction, RequestDirection), 'invalid direction specified in expression'
 
     if method.direction == RequestDirection.FROM:
-        assert context.text is None, f'Step text is not allowed for {method.name}'
+        assert context.text is None, f'step text is not allowed for {method.name}'
         assert direction == RequestDirection.FROM, f'"to endpoint" is not allowed for {method.name}, use "from endpoint"'
     elif method.direction == RequestDirection.TO:
-        assert context.text is not None, f'Step text is mandatory for {method.name}'
+        assert context.text is not None, f'step text is mandatory for {method.name}'
         assert direction == RequestDirection.TO, f'"from endpoint" is not allowed for {method.name}, use "to endpoint"'
 
     add_request_task(context, method=method, source=context.text, name=name, endpoint=endpoint)
@@ -164,7 +164,7 @@ def step_task_request_file_with_name_endpoint(context: Context, method: RequestM
         name (str): name of the requests in logs, can contain variables
         endpoint (str): URI relative to `host` in the scenario, can contain variables and in certain cases `user_class_name` specific parameters
     '''
-    assert method.direction == RequestDirection.TO, f'{method.name} not allowed'
+    assert method.direction == RequestDirection.TO, f'{method.name} is not allowed'
     assert context.text is None, f'Step text is not allowed for {method.name}'
     add_request_task(context, method=method, source=source, name=name, endpoint=endpoint)
 
@@ -199,7 +199,7 @@ def step_task_request_file_with_name(context: Context, method: RequestMethod, so
         source (str): path to a template file relative to the directory `requests/`, which **must** exist in the directory the feature file is located
         name (str): name of the requests in logs, can contain variables
     '''
-    assert method.direction == RequestDirection.TO, f'{method.name} not allowed'
+    assert method.direction == RequestDirection.TO, f'{method.name} is not allowed'
     assert context.text is None, f'Step text is not allowed for {method.name}'
     add_request_task(context, method=method, source=source, name=name)
 
